# {{project_title}}

This curated repository is based on the [ColRev](https://github.com/CoLRev-Environment/colrev) standard.

- It provides curated metadata and PDF hashes.
- Additional metadata should be curated in derivative repositories
- Corrections are welcome and should be provided using a pull-request on GitHub (initiated by the `colrev push` operation)

```
# To install the curated metadata, run
colrev env --install {{url}}
colrev env --index
```
